Modules
- coord
- Coordinate utilities for Zarr array flattening
- dtype
- Data type parsing and conversion utilities for Zarr arrays
- filter
- Filter pushdown support for Zarr queries
- schema_
inference - Schema inference for Zarr v2 and v3 stores
- stats
- I/O statistics for Zarr reads
- storage
- Storage backend factory for local and cloud object stores.
- tracked_
store - A storage adapter that tracks disk I/O bytes.
- zarr_
reader - Zarr array reader that flattens nD data into Arrow RecordBatches